HISTORY
-------

0.1 (2012-09-12)
^^^^^^^^^^^^^^^^

* Support input as XML format.
* MovableType format is no longer supported.
* Pystache is no longer used.


prototype (2012-03-31)
^^^^^^^^^^^^^^^^^^^^^^

* Prototype release
